@@ -13,7 +13,7 @@ from .remote_indicator_evaluator import *
 class QuantEngineClient:
     MultiplyFactor = ((60 * 24) / 405)
 
-    def __init__(self, url, apikey, launchmode, sid, user_id, trace_ws):
+    def __init__(self, url, apikey, launchmode, sid, user_id, trace_ws=False):
         self.Url = url
         self.ApiKey = apikey
         self.UserId = user_id
